% MtConnectDatabase opens a database connection.
%
%   [status] = MtConnectDatabase (connection, host, database);
%   [status] = MtConnectDatabase (connection, host, database, user, password);
%
%   Connections to several different databases can be opened simultaneously. 
%   To select a connection to work on, call MtSetCurrentConnection. 
%
%   OUTPUT [1]
%
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise a string other than 'MATISSE_SUCCESS' is returned.
%
%   INPUT [3 or 5]
%
%      connection: number
%          The pointer to a previously allocated structure that will contain all  
%          the information about the database connection.
%           
%      host: string
%          The host where the database is located.
%
%      databaseName: string
%          The name of the database to connect to.
%
%      userName: string (optional)
%          The name of the database user. May be set to NULL; in this case the 
%          login name of the user is used.
%
%      password: string (optional)
%          The user password. Can be set to NULL only if the user name is also NULL.
%
%   Example:
%
%   [status, conn] = MtAllocateConnection;
%   status = MtConnectDatabase (conn, 'amelie.wins.uva.nl', 'Video501');
%   status = MtDisconnectDatabase (conn);
%   status = MtFreeConnection (conn);
%
%   See also: 
%      MatisseConnection

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 5.3.1.29215a (R11.1) - Matisse 5.0b2
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    July 2001   
