% MtGetSelectionNumberObjects retrieves the number of objects in a selection.
%
%   [status, numberObjects] = MtGetSelectionNumberObjects;
%   [status, numberObjects] = MtGetSelectionNumberObjects (selection);
%
%   If no selection argument is given, the function uses the unnamed selection of 
%   the currentcontext if one exists.
%
%   INPUT [1]
%      selection: number or string
%         The key or the name of the selection produced by the successful
%         execution of a SQL SELECT statement.
%
%   OUTPUT [2]
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise 'MATISSE_INVALARG' is returned.
%
%      numberObjects: number
%          The number of objects in the selection.
%            
%   Example:
%
%   % the usage of the function MtGetSelectionNumberObjects
%
%   [status, conn] = MtAllocateConnection;
%   status = MtConnectDatabase (conn, 'amelie.wins.uva.nl', 'Video501');
%   status = MtSetCurrentConnection (conn);
%
%   [status, stmt] = MtSQLAllocStmt;
%   [status, stmt] = MtSQLExecDirect (stmt, 'SELECT Title FROM Movie');
%
%   [status, selection] = MtGetSelection;
%   
%   [status, numberObjects] = MtGetSelectionNumberObjects (selection)
%   
%   status = MtSQLFreeStmt (stmt);
%   status = MtEndVersionAccess;
%   status = MtNoCurrentConnection;
%   status = MtDisconnectDatabase (conn);
%   status = MtFreeConnection (conn);

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 6.0.0.88 (R12) - Matisse 5.0.1
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    December 2001

