% MtNextProperty gives the subsequent property in the stream
%
%   [status, property, specified] = MtNextProperty (stream);
%
%   Depending on the stream type (mapping the attributes, the relationships, or 
%   the inverse relationships), the stream includes the identifiers of either all 
%   the attributes or relationships defined for the object, or all the inverse 
%   relationships present in the object.
%
%   If the stream has been opened with the MtOpenInverseRelationshipsStream function, 
%   the return value 'specified' is always set to 1 (MT_TRUE) because the supplied 
%   properties are those present in the object.
%
%   Once all the properties have been accessed, the function 
%   returns MATISSE_ENDOFSTREAM, and object is set to 0.
%
%   This function can be called inside a transaction or during a version access.
%
%
%   OUTPUT [3]
%
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise a string other than 'MATISSE_SUCCESS' is returned.
%    
%      property: number
%          The key to the attribute or relationship, or NULL if there is no 
%          subsequent property. 
%
%      specified: number
%          indicates if the property of the object is ever explicitly set, or that the
%          object still contains the default value from the schema. Specified is set to 
%          MT_TRUE (1) when the attribute has a value, and is set to MT_FALSE (0) when  
%          the attribute value is still the attribute default value. 
%
%   INPUT [1]
%
%      stream: number
%          A  properties stream (attribute, relationship or inverse relationship stream)
%
%   See also: 
%      MtOpenAttributesStream
%      MtOpenInverseRelationshipsStream
%      MtOpenRelationshipsStream

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 5.3.1.29215a (R11.1) - Matisse 5.0b2
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    July 2001   

