% MtOpenInverseRelationshipsStream initializes the stream of inverse relationships 
%
%   [status, stream] = MtOpenRelationshipsStream (object);
%
%   The function opens the inverse relationship stream on the specified object. The function 
%   MtNextProperty will use the stream to provide the user with the different inverse  
%   relationships of the object.
%
%   An instance of a class can have a relationship that is not defined in the class.
%
%   A stream opened by the function MtOpenInverseRelationshipsStream visits only those 
%   inverse relationships that do exist for an object.
% 
%   It can sometimes be useful to know all the types of inverse relationships that can 
%   exist for instances of a particular class. You can retrieve this information with 
%   the GetAllInverseRelationships functions. These functions return a listing of all 
%   the types of possible inverse relationships of a class.
%
%   MtGetAllInverseRelRelationships retrieves information on all the possible inverse 
%   relationships implied at the schema level. MtOpenInverseRelationshipsStream retrieves, 
%   for an instance of a given class, all the inverse relationships that have been
%    established for it.
%
%   The  function can be called either inside a transaction or during version access.
%
%   OUTPUT [2]
%
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise a string other than 'MATISSE_SUCCESS' is returned.
%    
%      stream: number
%          A inverse relationship stream.
%
%   INPUT [1]
%
%     object: number
%           The key to an object.
%
%   See also: 
%      MtGetAllInverseRelationships
%      MtCloseStream
%      MtNextProperty
%

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 5.3.1.29215a (R11.1) - Matisse 5.0b2
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    July 2001  
