% MtSQLGetSelectionName retrieves the name of a selection.
%
%   [status, selectionName] = MtSQLGetSelectionName (selection);
%
%   If the selection passed in argument is not named, the value returned is NULL.
%
%   INPUT [1]
%      selection: number
%         The key to the selection produced by the successful
%         execution of a SQL SELECT ... INTO statement.
%
%   OUTPUT [2]
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise 'MATISSE_INVALARG' is returned.
%
%      selectionName: string
%          The name of the selection to be retrieved.
%           
%   Example:
%
%   [status, sqlResult] = ...
%          MtSQLExec ('CONNECT TO "VideoStore"');
%   [status, sqlResult] = ...
%          MtSQLExec ('SELECT * FROM MOVIE INTO M');
%   
%   [status, selection] = MtSQLGetSelection('M');
%   [status, name] = MtSQLGetSelectionName (selection)
%   
%   [status] = MtSQLFreeSelection (selection);
%   [status, sqlResult] = MtSQLExec ('ROLLBACK');
%   [status, sqlResult] = MtSQLExec ('DISCONNECT CURRENT');

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 5.3.1.29215a (R11.1) - Matisse 5.0b2
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    July 2001  
