% MtSQLNext fetch the next row from the selection.
%
%   status = MtSQLNext (stream);
%
%   Fetch the next row from a SQL selection produced by the successful execution 
%   of a SQL statement. The values for the columns of the current row can then be 
%   retrieved with the functions MtSQLGetRowValue and MtSQLGetRowListElements.
%
%   MtSQLNext should be used instead of MtNextObject in order to retrieve the 
%   colum values for a SQL result set. In particular, this interface allows to 
%   retrieve computed values like COUNT, AVG, SUM.
%
%
%   OUTPUT [1]
%
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise a string other than 'MATISSE_SUCCESS' is returned.
%
%   INPUT [1]
%
%      stream: number
%          A class stream, an entry-point stream, a relationship stream, 
%          a selection stream or an inverse relationship stream.
%
%   See also: 
%      MatisseSQL
 
%   Example (MtOpenSelectionStream doesn't work):
%   %  The following example shows how to execute a SELECT statement and  
%   %  retrieve the values for the 1st column with the projection API.
%
%   colnum = 1;
%   [status, conn] = MtAllocateConnection;
%   status = MtConnectDatabase (conn, 'amelie.wins.uva.nl', 'Video501');
%   status = MtSetCurrentConnection (conn);
%
%   [status, stmt] = MtSQLAllocStmt;
%   [status, stmt] = MtSQLExecDirect (stmt, 'SELECT Title FROM Movie');
%
%   [status, selection] = MtGetSelection;
%
%   [status, stream] = MtOpenSelectionStream (selection);
%   status = MtSQLNext (stream);
%
%   while strcmp (status, 'MATISSE_SUCCESS');
%
%        [status, type, title, size] = ...
%               MtSQLGetRowValue(stream, colnum, 'MT_STRING', 1, 1024);
%        title
%        status = MtSQLNext (stream);
%   end
%   
%   status = MtCloseStream (stream);
%   status = MtSQLFreeStmt (stmt);
%   status = MtEndVersionAccess;
%   status = MtNoCurrentConnection;
%   status = MtDisconnectDatabase (conn);
%   status = MtFreeConnection (conn);

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 6.0.0.88 (R12) - Matisse 5.0.1
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    December 2001

