% MtSQLOpenSelectionStream opens a stream that contains the objects of a selection.
%
%   [status, stream] = MtSQLOpenSelectionStream (selection);
%
%   The stream that this function opens will contain the instances of the objects 
%   that were previously selected. The selection stream can be manipulated like any 
%   MATISSE stream. The instances can be retrieved with the function MtNextObject 
%   and the stream can be closed with the function MtCloseStream.
%
%   INPUT [1]
%      selection: number or string
%         The key or name of the selection to be renamed.
%
%   OUTPUT [2]
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise 'MATISSE_INVALARG' is returned.
%           
%      stream: number
%          The key to the object stream that will contain the instances meeting 
%          the selection criteria.
%
%   See also:
%      MatisseSQL
%
%   colnum = 1;
%   [status, sqlResult] = ...
%          MtSQLExec ('CONNECT TO "VideoStore"');
%   [status, sqlResult] = MtSQLExec ('SELECT Title FROM Movie');
%
%   [status, selection] = MtSQLGetSelection;
%   
%   [status, stream] = MtSQLOpenSelectionStream (selection);
%   status = MtSQLNextRow(stream);
%
%   while strcmp (status, 'MATISSE_SUCCESS');
%
%        [status, type, title, size] = ...
%               MtSQLGetRowValue(stream, colnum, 'MT_STRING', 1, 1024);
%        title
%        status = MtSQLNextRow(stream);
%   end
%   
%   status = MtCloseStream (stream);
%   status = MtSQLFreeSelection (selection);
%   [status, sqlResult] = MtSQLExec ('ROLLBACK');
%   [status, sqlResult] = MtSQLExec ('DISCONNECT CURRENT');

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 5.3.1.29215a (R11.1) - Matisse 5.0b2
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    July 2001

