% MtSetListElements stores a list as a subset of an existing list attribute.
%
%   status = ...
%      MtSetListElements (object, attribute, type, bufList, numElts, offset, discard);
%
%   This function stores the bufList content as a subset of the existing list value 
%   of the attribute for the specified object. The subset is stored from offset's 
%   element and is numElts long.
%
%   OUTPUT [1]
%
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise a string other than 'MATISSE_SUCCESS' is returned.
%    
%   INPUT [7]
%
%      object: number
%          The key to an object. 
%
%      attribute: number or string
%          The key or the name of an attribute.
%
%      type: number or string
%          The expected type of the list value. Possible types are all of the format
%          'MT_*_LIST'.
%
%      bufList: number
%          The key to the subset to be stored. 
%
%      numElts: number
%          The number of elements of the subset. 
%
%      offset: number or string
%          The offset (or position) of an element in the list value. The subset will 
%          be stored starting at this offset. The first element in the list value has 
%          the offset 0. 
%
%          Three specific values are allowed:
%          - 'MT_BEGIN_OFFSET',
%          - 'MT_CURRENT_OFFSET',
%          - 'MT_END_OFFSET'
%         The second one means "the next element immediately after the last accessed 
%         element". 
%
%      discard: number
%          This flag indicates whether or not the rest of the existing list 
%          immediately after the subset (i.e from the element at offset + numElts 
%          until the end) have to be discarded.  
%
% See also:
%   MtGetListElements
%   MtGetValue 
%   MtSetValue 

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 5.3.1.29215a (R11.1) - Matisse 5.0b2
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    July 2001

